import { Injectable, CanActivate, ExecutionContext, Logger } from '@nestjs/common';
import { Reflector } from '@nestjs/core';
import { ConfigService } from '../configuration/config.service';

@Injectable()
export class GroupsGuard implements CanActivate {

  private logger: Logger;

  constructor(
    private readonly reflector: Reflector,
    private configService: ConfigService,
  ) {
    this.logger = new Logger(GroupsGuard.name);
  }

  canActivate(context: ExecutionContext): boolean {

    this.logger.log('Entering function', `${GroupsGuard.name} - ${this.canActivate.name}`);
    // We get the groups specified on the endpoint with the @Groups annotation
    // We need then to get the real group names associated to those keys from the config file
    let groups = this.reflector.get<string[]>('groups', context.getHandler());

    // if no groups specified then access is always ok
    if (!groups) {
      return true;
    }

    groups = groups.map((e) => {
      return this.configService.config.groupNames[e];
    });

    // if the spcified group is not found
    if (!groups) {
      return true;
    }

    // Get the group from the header
    const request = context.switchToHttp().getRequest();
    const groupHeader = request.headers[this.configService.config.groupHeader];

    if (!groupHeader) {
      this.logger.log('No group header');
      return false;
    }

    const consumerGroups = groupHeader.split(',').map(e => e.trim());

    this.logger.log(`Consumer groups: ${consumerGroups}`);

    const hasGroup = () => consumerGroups.some((group) => groups.includes(group));

    return consumerGroups && hasGroup();
  }
}