import { HealthIndicatorResult } from '@nestjs/terminus';
import { Injectable, Logger } from '@nestjs/common';
import { HealthCheckError } from '@godaddy/terminus';
import { HealthIndicator } from '@nestjs/terminus/dist/health-indicators/abstract/health-indicator';
import * as Nodemailer from 'nodemailer';
import { ConfigService } from '../configuration/config.service';

@Injectable()
export class SmtpHealthIndicator extends HealthIndicator {

  private logger: Logger;

  constructor(
    private configService: ConfigService,
  ) {
    super();
    this.logger = new Logger(SmtpHealthIndicator.name);
  }

  async checkSMTPConnection(): Promise<HealthIndicatorResult> {

    const transporter = Nodemailer.createTransport(this.configService.config.smtpConfig);

    await transporter.verify().catch((error) => {
      this.logger.error('SMTP connection failed.', `${error}`, `${SmtpHealthIndicator.name} - ${this.checkSMTPConnection.name}`);
      transporter.close();
      throw new HealthCheckError('SMTP connection failed', error);
    });

    transporter.close();
    return this.getStatus('smtpServer', true);

  }
}